<?php

namespace Asadi\Parent\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Parent\Interfaces\ParentRepositoryInterface;
use Asadi\Parent\Repositories\Presenter\ParentItemTransformer;

/**
 * Pubic API controller class.
 */
class ParentPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Parent\Interfaces\ParentRepositoryInterface $parent
     *
     * @return type
     */
    public function __construct(ParentRepositoryInterface $parent)
    {
        $this->repository = $parent;
        parent::__construct();
    }

    /**
     * Show parent's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $parents = $this->repository
            ->setPresenter('\\Asadi\\Parent\\Repositories\\Presenter\\ParentListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $parents['code'] = 2000;
        return response()->json($parents)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show parent.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $parent = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($parent)) {
            $parent         = $this->itemPresenter($module, new ParentItemTransformer);
            $parent['code'] = 2001;
            return response()->json($parent)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
