<?php

namespace Asadi\Parent\Http\Controllers;
use Litepie\Parent\Http\Requests\ParentRequest;
use Litepie\Parent\Models\Parent;

trait ParentWorkflow {
	
    /**
     * Workflow controller function for parent.
     *
     * @param Model   $parent
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ParentRequest $request, Parent $parent, $step)
    {

        try {

            $parent->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('parent::parent.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/parent/parent/' . $parent->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/parent/parent/' . $parent->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for parent.
     *
     * @param Model   $parent
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Parent $parent, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $parent->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('parent::parent.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('parent::admin.parent.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('parent::admin.parent.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('parent::admin.parent.message', $data)->render();

        }

    }
}