<?php

namespace Asadi\Parent\Policies;

use App\User;
use Asadi\Parent\Models\Parent;

class ParentPolicy
{

    /**
     * Determine if the given user can view the parent.
     *
     * @param User $user
     * @param Parent $parent
     *
     * @return bool
     */
    public function view(User $user, Parent $parent)
    {
        if ($user->canDo('parent.parent.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $parent->user_id;
    }

    /**
     * Determine if the given user can create a parent.
     *
     * @param User $user
     * @param Parent $parent
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('parent.parent.create');
    }

    /**
     * Determine if the given user can update the given parent.
     *
     * @param User $user
     * @param Parent $parent
     *
     * @return bool
     */
    public function update(User $user, Parent $parent)
    {
        if ($user->canDo('parent.parent.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $parent->user_id;
    }

    /**
     * Determine if the given user can delete the given parent.
     *
     * @param User $user
     * @param Parent $parent
     *
     * @return bool
     */
    public function destroy(User $user, Parent $parent)
    {
        if ($user->canDo('parent.parent.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $parent->user_id;
    }

    /**
     * Determine if the given user can verify the given parent.
     *
     * @param User $user
     * @param Parent $parent
     *
     * @return bool
     */
    public function verify(User $user, Parent $parent)
    {
        if ($user->canDo('parent.parent.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('parent.parent.verify') 
        && $user->is('manager')
        && $parent->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given parent.
     *
     * @param User $user
     * @param Parent $parent
     *
     * @return bool
     */
    public function approve(User $user, Parent $parent)
    {
        if ($user->canDo('parent.parent.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
