<?php

namespace Asadi\Parent\Providers;

use Illuminate\Support\ServiceProvider;

class ParentServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'parent');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'parent');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('parent', function ($app) {
            return $this->app->make('Asadi\Parent\Parent');
        });

        // Bind Parent to repository
        $this->app->bind(
            \Asadi\Parent\Interfaces\ParentRepositoryInterface::class,
            \Asadi\Parent\Repositories\Eloquent\ParentRepository::class
        );

        $this->app->register(\Asadi\Parent\Providers\AuthServiceProvider::class);
        $this->app->register(\Asadi\Parent\Providers\EventServiceProvider::class);
        $this->app->register(\Asadi\Parent\Providers\RouteServiceProvider::class);
        // $this->app->register(\Asadi\Parent\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['parent'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('asadi/parent.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/parent')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/parent')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
