<?php

namespace Asadi\Parent\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Parent\Models\Parent;

class ParentAction
{
    /**
     * Perform the complete action.
     *
     * @param Parent $parent
     *
     * @return Parent
     */
    public function complete(Parent $parent)
    {
        try {
            $parent->status = 'complete';
            return $parent->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Parent $parent
     *
     * @return Parent
     */public function verify(Parent $parent)
    {
        try {
            $parent->status = 'verify';
            return $parent->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Parent $parent
     *
     * @return Parent
     */public function approve(Parent $parent)
    {
        try {
            $parent->status = 'approve';
            return $parent->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Parent $parent
     *
     * @return Parent
     */public function publish(Parent $parent)
    {
        try {
            $parent->status = 'publish';
            return $parent->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Parent $parent
     *
     * @return Parent
     */
    public function archive(Parent $parent)
    {
        try {
            $parent->status = 'archive';
            return $parent->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Parent $parent
     *
     * @return Parent
     */
    public function unpublish(Parent $parent)
    {
        try {
            $parent->status = 'unpublish';
            return $parent->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
