<?php

namespace Asadi\Parent\Workflow;

use Asadi\Parent\Models\Parent;
use Validator;

class ParentValidator
{

    /**
     * Determine if the given parent is valid for complete status.
     *
     * @param Parent $parent
     *
     * @return bool / Validator
     */
    public function complete(Parent $parent)
    {
        return Validator::make($parent->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given parent is valid for verify status.
     *
     * @param Parent $parent
     *
     * @return bool / Validator
     */
    public function verify(Parent $parent)
    {
        return Validator::make($parent->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given parent is valid for approve status.
     *
     * @param Parent $parent
     *
     * @return bool / Validator
     */
    public function approve(Parent $parent)
    {
        return Validator::make($parent->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given parent is valid for publish status.
     *
     * @param Parent $parent
     *
     * @return bool / Validator
     */
    public function publish(Parent $parent)
    {
        return Validator::make($parent->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given parent is valid for archive status.
     *
     * @param Parent $parent
     *
     * @return bool / Validator
     */
    public function archive(Parent $parent)
    {
        return Validator::make($parent->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given parent is valid for unpublish status.
     *
     * @param Parent $parent
     *
     * @return bool / Validator
     */
    public function unpublish(Parent $parent)
    {
        return Validator::make($parent->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
